@@ -5,7 +5,7 @@ from . import APP_NAME, APP_VERSION, APP_DESCRIPTION, CONFIG_DIR, CACHE_DIR
 from .app import App
 from .meta import Meta
 from .can import MagicCANBus, MessageTable
-from .parse import CANOpenParser, load_eds_file
+from .parse import CANOpenParser, load_eds_files
 
 
 def init_dirs():
@@ -13,16 +13,6 @@ def init_dirs():
     os.makedirs(CACHE_DIR, exist_ok=True)
 
 
-def load_eds_files(filepath: str = CACHE_DIR) -> dict:
-    configs = {}
-    for file in os.listdir(filepath):
-        full_path = f'{filepath}/{file}'
-        if file.lower().endswith(".eds") or file.lower().endswith(".dcf"):
-            config = load_eds_file(full_path)
-            configs[config.node_id] = config
-    return configs
-
-
 def main():
     parser = argparse.ArgumentParser(prog=APP_NAME,
                                      description=APP_DESCRIPTION,
@@ -47,20 +37,21 @@ def main():
                         help='Display the app version then exit.')
     args = parser.parse_args()
 
-    if(args.version):
+    if (args.version):
         print(f'{APP_NAME} v{APP_VERSION}\n\n{APP_DESCRIPTION}')
         sys.exit(0)
 
     try:
         init_dirs()
-        eds_configs = load_eds_files()
-        mt = MessageTable(CANOpenParser(eds_configs))
         meta = Meta(CONFIG_DIR, CACHE_DIR)
-        interfaces = meta.load_devices(args.interfaces)
+        features = meta.load_features()
+        eds_configs = load_eds_files(CACHE_DIR, features.ecss_time)
+        mt = MessageTable(CANOpenParser(eds_configs))
+        interfaces = meta.load_interfaces(args.interfaces)
 
         # Start the can bus and the curses app
         with MagicCANBus(interfaces, no_block=args.no_block) as bus, \
-             App(mt, eds_configs, bus, meta) as app:
+                App(mt, eds_configs, bus, meta, features) as app:
             while True:
                 # Bus updates
                 for message in bus:
