@@ -10,7 +10,7 @@ class MessageTable:
     def __add__(self: MessageTable, message: Message) -> MessageTable:
         if(self.parser is not None):
             message.node_name = self.parser.get_name(message)
-            message.message = self.parser.parse(message)
+            message.message, message.error = self.parser.parse(message)
         self.table[message.arb_id] = message
         return self
 
@@ -20,11 +20,14 @@ class MessageTable:
     def filter(self: MessageTable,
                types: MessageType,
                start: int = 0,
-               end: int = None) -> [Message]:
+               end: int = None,
+               sort_by: str = 'arb_id',
+               reverse=False) -> [Message]:
         end = len(self.table) if end is None else end
         messages = list(filter(lambda x: x.type in types
                         or x.supertype in types, self.table.values()))
-        return messages[start:end]
+        slice = messages[start:end]
+        return sorted(slice, key=lambda x: getattr(x, sort_by), reverse=reverse)
 
     def __contains__(self: MessageTable, node_id: int) -> bool:
         return node_id in self.table
