@@ -546,3 +546,36 @@ class TestSDO(unittest.TestCase):
 
         self.assertEqual("Invalid SDO payload length, expected 8, received "
                           "0", str(context.exception))
+
+    def test_expedited_invalid_index(self):
+        """
+        Text expedited SDO transfer with an invalid index being used
+        """
+        parser = SDOParser()
+        client_initiate_message = [0x27, 0xFF, 0xFF, 0x00, 0x0A, 0x00, 0x00,
+                                   0x00]
+        with self.assertRaises(FailedValidationError) as context:
+            parser.parse(0x600, client_initiate_message, self.eds_data)
+
+        self.assertEqual("SDO provided index does not exist. Check provided "
+                         "index 'ffff'", str(context.exception))
+
+        self.assertEqual(False, parser.is_complete,
+                         "Parser should be incomplete")
+
+    def test_expedited_invalid_subindex(self):
+        """
+        Text expedited SDO transfer with a valid index and invalid subindex
+        being used
+        """
+        parser = SDOParser()
+        client_initiate_message = [0x27, 0x10, 0x18, 0x07, 0x0A, 0x00, 0x00,
+                                   0x00]
+        with self.assertRaises(FailedValidationError) as context:
+            parser.parse(0x600, client_initiate_message, self.eds_data)
+
+        self.assertEqual("SDO provided index does not exist. Check provided "
+                         "index '1018sub7'", str(context.exception))
+
+        self.assertEqual(False, parser.is_complete,
+                         "Parser should be incomplete")
